<?php
// $Id: rawlog.admin.inc,v 1.1.2.11 2010/04/19 23:03:51 vitoa Exp $

/**
 * Rawlog module settings.
 */
function rawlog_admin_settings() {
  // Use javascript for some added usability on admin form.
  $files_folder = '<script type="text/javascript">var files_folder = "'. addslashes(file_directory_path()) .'/";</script>';
  
  drupal_add_js(drupal_get_path('module', 'rawlog') .'/rawlog.js');

  $form['#prefix'] .= $files_folder;
  
  // Configuration option for the log file name.
  $form['rawlog_filename'] = array(
    '#type' => 'textfield', 
    '#title' => t('Log file name'), 
    '#default_value' => variable_get('rawlog_filename', drupal_get_path('module', 'rawlog') .'/rawlog_@date.log'), 
    '#description' => t('Please specify a path to your log file. Web server must have write permission to the file. If file doesn&quot;t exists, it will be created.<br />You should place a @date placeholder for current date/time in the file name for log files to be rotated periodically.<br />Currently log lile name is set to be <span>%file</span>.', array('%file' => rawlog_update_filename())),
  );

  // Configuration option for placing the log file to the files folder.
  $form['rawlog_place_to_files'] = array(
    '#type' => 'checkbox',
    '#title' => t('Place to the files folder'),
    '#description' => t('Place the log file to the files folder. Use with care - will change your previous entered log file path leaving the file name.<br />Will not keep your previous entered log file path and restore if unchecked. If you don&quot;t want it to be replaced after checkbox checking, navigate away from the settings page instantly do not saving the options.'),
    '#default_value' => variable_get('rawlog_place_to_files', FALSE),
  );
  
  // System events severity list.
  $severity_list = rawlog_severity_list();
  $form['rawlog_severity_level'] = array(
    '#type' => 'select',
    '#title' => t('Severity level'),
    '#description' => t('Minimum severity level for system events to include in the log.'),
    '#options' => $severity_list,
    '#default_value' => variable_get('rawlog_severity_level', 4),
  );

  $form['rawlog_tag_settings'] = array(
    '#type' => 'fieldset', 
    '#title' => t('Tagging'),
    '#description' => t('You may configure additional settings to include events having a corresponding tags (keywords) here.'),
    '#collapsible' => TRUE, 
    '#collapsed' => TRUE,
  );

  $rawlog_enable_tags = variable_get('rawlog_enable_tags', FALSE);
  
  $form['rawlog_tag_settings']['rawlog_enable_tags'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable tags'),
    '#default_value' => $rawlog_enable_tags,
    '#description' => t('Enable filtering of events based on a corresponding tags (keywords).'),
    '#weight' => 1,
  );

  $form['rawlog_tag_settings']['rawlog_tags'] = array(
    '#type' => 'textfield',
    '#title' => t('Tags'),
    '#description' => t('Please list the comma-separated tags (keywords) here. This may be useful if you having lots of activity on site so set severity level high to record only errors themselves not notices etc. Events having tags listed will be logged disregarding of their severity.'),
    '#default_value' => variable_get('rawlog_tags', ''),
    '#weight' => 2,
    '#disabled' => !$rawlog_enable_tags,
  );

  $form['rawlog_format_settings'] = array(
    '#type' => 'fieldset', 
    '#title' => t('File format'),
    '#description' => t('You may configure file format settings here.'),
    '#collapsible' => TRUE, 
    '#collapsed' => TRUE,
  );

  $file_format_options = array('short' => t('Short'), 'medium' => t('Medium'), 'full' => t('Full'));

  $form['rawlog_format_settings']['rawlog_file_format'] = array(
    '#type' => 'radios',
    '#title' => t('File format'),
    '#default_value' => variable_get('rawlog_file_format', 'medium'),
    '#options' => $file_format_options,
    '#description' => t('Configure file format settings here. Misc. message text formatting options like event fields and field titles to include and skip, lines per event count etc. are depending on it.'),
  );

  $form['rawlog_rotation_settings'] = array(
    '#type' => 'fieldset', 
    '#title' => t('Logs rotation'),
    '#description' => t('You may configure logs rotation settings here.'),
    '#collapsible' => TRUE, 
    '#collapsed' => TRUE,
  );

  $logs_rotation_options = array('hour' => t('Hourly'), 'day' => t('Daily'), 'week' => t('Weekly'), 'month' => t('Monthly'), 'never' => t('Never'));

  $form['rawlog_rotation_settings']['rawlog_logs_rotation'] = array(
    '#type' => 'radios',
    '#title' => t('Logs rotation'),
    '#default_value' => variable_get('rawlog_logs_rotation', 'never'),
    '#options' => $logs_rotation_options,
    '#description' => t('Configure logs rotation settings here. This will set how often the log file will change - daily, weekly, monthly or never'),
    '#weight' => 1,
  );

  $current_format = variable_get('rawlog_filedate_format', 'Y-m-d_H-i-s');
  $form['rawlog_rotation_settings']['rawlog_filedate_format'] = array(
    '#type' => 'textfield',
    '#title' => t('File date format'),
    '#description' => t('Configure file date format for file naming here. See the <a href="@url">PHP manual</a> for available options. This format is currently set to display as <span>%date</span>.', array('@url' => 'http://php.net/manual/function.date.php', '%date' => date($current_format))),
    '#default_value' => $current_format,
    '#weight' => 2,
  );

  $full_form = system_settings_form($form);
  $full_form['#submit'][] = 'rawlog_admin_settings_submit';
  
  return $full_form;
}

/**
 * Attempts to create a log file when the admin settings form is submitted.
 */
function rawlog_admin_settings_submit($form, &$form_state) {
  // Attempt to create the log file if not exists.
  $filename = isset($form_state['values']['rawlog_filename']) ? $form_state['values']['rawlog_filename'] : '';
  $logfile = rawlog_update_filename($filename);
  if ($logfile && !file_exists($logfile)) {
    rawlog_create_logfile();
  }
}
